summaryrefslogtreecommitdiffstats
path: root/ipalib/config.py
diff options
context:
space:
mode:
authorJason Gerard DeRose <jderose@redhat.com>2008-12-23 01:59:31 -0700
committerJason Gerard DeRose <jderose@redhat.com>2008-12-23 01:59:31 -0700
commit7766f0be6189c06c3cbbdef59bdbf4eb2a65e2a1 (patch)
tree17375b753ff3abb25550977afe0f34c01d57f18f /ipalib/config.py
parentf7cae9a27cde3346783809cbf949762b0c0708f1 (diff)
downloadfreeipa-7766f0be6189c06c3cbbdef59bdbf4eb2a65e2a1.tar.gz
freeipa-7766f0be6189c06c3cbbdef59bdbf4eb2a65e2a1.tar.xz
freeipa-7766f0be6189c06c3cbbdef59bdbf4eb2a65e2a1.zip
Yet more small docstring cleanup in Env
Diffstat (limited to 'ipalib/config.py')
-rw-r--r--ipalib/config.py9
1 files changed, 5 insertions, 4 deletions
diff --git a/ipalib/config.py b/ipalib/config.py
index 8c602cdc3..dc5d35f8b 100644
--- a/ipalib/config.py
+++ b/ipalib/config.py
@@ -42,7 +42,7 @@ class Env(object):
environment variables. These variables can be both set *and* retrieved
either as attributes *or* as dictionary items.
- For example, we can set a variable as an attribute:
+ For example, you can set a variable as an attribute:
>>> env = Env()
>>> env.attr = 'I was set as an attribute.'
@@ -51,7 +51,7 @@ class Env(object):
>>> env['attr'] # Also retrieve as a dictionary item
'I was set as an attribute.'
- Or we can set a variable as a dictionary item:
+ Or you can set a variable as a dictionary item:
>>> env['item'] = 'I was set as a dictionary item.'
>>> env['item']
@@ -166,7 +166,8 @@ class Env(object):
process.
However, normally none of the above methods are called directly and instead
- only `ipalib.plugable.API.bootstrap()` is called.
+ only `plugable.API.bootstrap()` is called, which itself takes care of
+ correctly calling the `Env` bootstrapping methods.
"""
__locked = False
@@ -360,7 +361,7 @@ class Env(object):
After this method finishes, the `Env` instance will be locked and no
more environment variables can be set. Aside from unit-tests and
example code, normally only one `Env` instance is created, meaning
no more variables can be set during the remaining life of the process.
"""
self.__doing('_finalize')
@@ -360,7 +361,7 @@ class Env(object):
After this method finishes, the `Env` instance will be locked and no
more environment variables can be set. Aside from unit-tests and
- example code, normally only one `Env` instance is created, meaning
+ example code, normally only one `Env` instance is created, which means
no more variables can be set during the remaining life of the process.
"""